Malformed Page - OpenRouter

# test/malformed-model

Provider | Throughput | Latency
--- | --- | ---
Provider1 | 10.5 TPS | 1.2s
Provider2
Provider3 | 8.2 TPS | 0.9s | Extra Cell | Another Extra
| 5.0 TPS | 2.1s
Provider4 | invalid TPS | bad latency

### CardProvider1

Performance: 15.0 tokens/s

Response time: 800ms

Availability: 99.1%

Throughput: 12.5 TPS

Latency: 1.1s

#### CardProvider2

This provider has no performance data